pub enum OutputMode {
Wrapping,
Saturating,
}Expand description
Output mode
Wrapping vs Saturating
Variants
Wrapping
Wrap result when it does not fit into a Q1.15
Saturating
Saturate result when it does not fit into a Q1.15